lsm303d Accelerometer And Compass
=================================

Suitable for measuring orientation and motion, the lsm303d has a 3-axis
accelerometer and compass.

Installing
==========

Stable library from PyPi:

-  Just run ``sudo pip install lsm303d``

Latest/development library from GitHub:

-  ``git clone https://github.com/pimoroni/lsm303d-python``
-  ``cd lsm303d-python``
-  ``sudo ./install.sh``
